# CHANGELOG



## v0.4.1 (2024-01-08)

### Ci

* ci: run tests on prs against any branch (#39) ([`e21f947`](https://github.com/MartinBernstorff/herbarium/commit/e21f9477d183d65fd1d7701e691d1c46882a15ef))

* ci: run tests on prs against any branch ([`28c6035`](https://github.com/MartinBernstorff/herbarium/commit/28c603591f7b3037a610a8261c67a14f449aab39))

### Fix

* fix: prettier log

Fixes #35 ([`8e149ba`](https://github.com/MartinBernstorff/herbarium/commit/8e149ba4aa166e439138f027894b41a909798fe2))

### Unknown

* cli: reverse log output (#45)

cli: reverse log output

Fixes #44

cli: reverse log output

Fixes #44 ([`a4faa4b`](https://github.com/MartinBernstorff/herbarium/commit/a4faa4ba49ef31d6e2dad7b95e275b32909b0f72))

* cli: reverse log output

Fixes #44 ([`3d68811`](https://github.com/MartinBernstorff/herbarium/commit/3d6881183f9af53a875e67c9a2521fb9c960b58a))

* misc. ([`5213f14`](https://github.com/MartinBernstorff/herbarium/commit/5213f1453aa956db3bc17f349bdcda8c5b2d22c6))

* misc. ([`428c6ae`](https://github.com/MartinBernstorff/herbarium/commit/428c6aeeb101c1554f5515278829564ad2e73883))

* cli: simplify stack submit animations (#43)

cli: simplify stack submit animations

Fixes #42

misc. ([`d2e44b6`](https://github.com/MartinBernstorff/herbarium/commit/d2e44b60dbe2b96a5c4a7b56d3b0022c321de8a5))

* misc. ([`834beb9`](https://github.com/MartinBernstorff/herbarium/commit/834beb96486e0aee8efabe881543cc462af9db4f))

* dev: submit with automerge (#41)

dev: submit with automerge

Fixes #40

misc. ([`1657a46`](https://github.com/MartinBernstorff/herbarium/commit/1657a46d5e56d4855554458010c1da773e026451))

* misc. ([`0b43842`](https://github.com/MartinBernstorff/herbarium/commit/0b43842cf145ba29421fd2521cf8cc24b23ef326))

* dev: submit with automerge

Fixes #40 ([`144e52c`](https://github.com/MartinBernstorff/herbarium/commit/144e52ca324fc353070af6f2926fc74d7eb1e848))


## v0.4.0 (2024-01-08)

### Feature

* feat: delete unused branches on submit (#37)

feat: delete unused branches on submit

Fixes #30

misc.

fix: even prettier logs ([`45d6a50`](https://github.com/MartinBernstorff/herbarium/commit/45d6a50f0d7238790d0b657594987c1b678c648d))


## v0.3.1 (2024-01-08)

### Fix

* fix: prettier log (#36)

fix: prettier log

Fixes #35

fix: prettier log

Fixes #35 ([`4482f2c`](https://github.com/MartinBernstorff/herbarium/commit/4482f2c9dda485cc006ab5b299f412525a1eabc5))


## v0.3.0 (2024-01-08)

### Feature

* feat: newline after submitting stack to get log pretty (#34)

feat: newline after submitting stack to get log pretty

Fixes #31

misc. ([`99de3de`](https://github.com/MartinBernstorff/herbarium/commit/99de3ded14a272fe85e2e2a68a0e7ce555305a3f))

* feat: make automerge a command-line argument (#33)

Fixes #32 ([`6ecac7f`](https://github.com/MartinBernstorff/herbarium/commit/6ecac7f1ae9a2829d2696b0af8e226997e476ecc))


## v0.2.0 (2024-01-08)

### Feature

* feat: support python &gt;=3.9 (#28)

feat: support python &gt;=3.9

Fixes #27

feat: support python &gt;=3.9

Fixes #27

misc.

misc.

misc. ([`61d9402`](https://github.com/MartinBernstorff/herbarium/commit/61d9402f6601fbe85c6a6c2bec04d6211a4f8007))


## v0.1.0 (2024-01-07)

### Ci

* ci: fix release pipeline ([`e28c77c`](https://github.com/MartinBernstorff/herbarium/commit/e28c77ca98d35733ae3309265bc8d73d6ca9afe5))

* ci: setup release to pypi (#24)

ci: setup release to pypi

Fixes #21

ci: setup release to pypi

Fixes #21

tests: get tests running

misc.

ci: setup release.yml ([`3106412`](https://github.com/MartinBernstorff/herbarium/commit/3106412b885c832f12feaa75c1dc5d16c0088292))

### Feature

* feat: add GithubIssueService

Fixes #8. ([`c2939c3`](https://github.com/MartinBernstorff/herbarium/commit/c2939c3e12247e255293837076643fd6ae811451))

### Unknown

* misc. ([`79f4f2d`](https://github.com/MartinBernstorff/herbarium/commit/79f4f2df5ae0960c0ef15fb96f18ea30eb1eafc5))

* misc. ([`3ad9517`](https://github.com/MartinBernstorff/herbarium/commit/3ad95172a8addfe265cca73cef58c9ee69e5eae2))

* dev: create github cli dir on devcontainer init ([`58c40e6`](https://github.com/MartinBernstorff/herbarium/commit/58c40e6f34e14a1192a6ff177a53f5f417825ab8))

* misc. ([`8de39ac`](https://github.com/MartinBernstorff/herbarium/commit/8de39ac6cb6d45ab0c7066fa18553a4b7a2bade3))

* $feat: pretty cli animations with typer/rich (#23)

$feat: pretty cli animations with typer/rich

Fixes #13

$feat: pretty cli animations with typer/rich

Fixes #13

misc.

misc. ([`830040c`](https://github.com/MartinBernstorff/herbarium/commit/830040c8ec929215791ec495332ebefcc1eca7bd))

* dev: clean up gitignore (#22)

Fixes #19 ([`a58c808`](https://github.com/MartinBernstorff/herbarium/commit/a58c808497b99ee460ad38e840ed658a1a2d93f9))

* $fix: misc. types (#17)

$fix: misc. types

Fixes #14

$fix: misc. types

Fixes #14

refactor: cleanup

misc. ([`4342005`](https://github.com/MartinBernstorff/herbarium/commit/43420050f810d0bad2e6b85708d6d4449140e1c4))

* misc. ([`9d6b6de`](https://github.com/MartinBernstorff/herbarium/commit/9d6b6ded5bd4a56f0fa2f4731c65ef02d4e32ad1))

* Update README.md (#12) ([`f2d76a0`](https://github.com/MartinBernstorff/herbarium/commit/f2d76a05372650b192b47205bca60a3803549762))

* first commit ([`5af600e`](https://github.com/MartinBernstorff/herbarium/commit/5af600e2b31b082b6785271c806243553de5e7bf))
